summaryrefslogtreecommitdiff
path: root/src/mongo/db/server_options.h
diff options
context:
space:
mode:
authorLingzhi Deng <lingzhi.deng@mongodb.com>2020-07-01 00:14:47 -0400
committerEvergreen Agent <no-reply@evergreen.mongodb.com>2020-07-09 16:26:41 +0000
commit98cf395c1e85d015032a4ef542fb491c47d726c3 (patch)
treecfb5b52286f86006751a7a1a5f143d1cba907c04 /src/mongo/db/server_options.h
parentc8e9a31cd3c21b7b40864e39323fbf0823f79f61 (diff)
downloadmongo-98cf395c1e85d015032a4ef542fb491c47d726c3.tar.gz
SERVER-49063: Update FCV 4.6 constants to 4.5.1
Diffstat (limited to 'src/mongo/db/server_options.h')
-rw-r--r--src/mongo/db/server_options.h26
1 files changed, 13 insertions, 13 deletions
diff --git a/src/mongo/db/server_options.h b/src/mongo/db/server_options.h
index fb241af8e0a..3be5400522a 100644
--- a/src/mongo/db/server_options.h
+++ b/src/mongo/db/server_options.h
@@ -166,19 +166,19 @@ struct ServerGlobalParams {
* (4.4, Unset): Only 4.4 features are available, and new and existing storage
* engine entries use the 4.4 format
*
* kUpgradingTo46
* (4.4, 4.6): Only 4.4 features are available, but new storage engine entries
* use the 4.6 format, and existing entries may have either the
* 4.4 or 4.6 format
*
* kFullyUpgradedTo46
* (4.6, Unset): 4.6 features are available, and new and existing storage
* engine entries use the 4.6 format
*
- * kDowngradingTo44
+ * kDowngradingFrom451To44
* (4.4, 4.4): Only 4.4 features are available and new storage engine
* entries use the 4.4 format, but existing entries may have
- * either the 4.4 or 4.6 format
+ * either the 4.4 or 4.5.1 format
*
* kUnsetDefault44Behavior
* (Unset, Unset): This is the case on startup before the fCV document is
@@ -193,12 +193,12 @@ struct ServerGlobalParams {
// lower than some maximum, respectively.
kUnsetDefault44Behavior = 0,
kFullyDowngradedTo44 = 1,
- kDowngradingTo44 = 2,
- kUpgradingTo46 = 3,
- kFullyUpgradedTo46 = 4,
+ kDowngradingFrom451To44 = 2,
+ kUpgradingFrom44To451 = 3,
+ kVersion451 = 4,
};
- static constexpr Version kLatest = Version::kFullyUpgradedTo46;
+ static constexpr Version kLatest = Version::kVersion451;
static constexpr Version kLastContinuous = Version::kFullyDowngradedTo44;
static constexpr Version kLastLTS = Version::kFullyDowngradedTo44;
@@ -166,19 +166,19 @@ struct ServerGlobalParams {
* engine entries use the 4.4 format
*
- * kUpgradingTo46
- * (4.4, 4.6): Only 4.4 features are available, but new storage engine entries
- * use the 4.6 format, and existing entries may have either the
- * 4.4 or 4.6 format
+ * kUpgradingFrom44To451
+ * (4.4, 4.5.1): Only 4.4 features are available, but new storage engine entries
+ * use the 4.5.1 format, and existing entries may have either the
+ * 4.4 or 4.5.1 format
*
@@ -166,19 +166,19 @@ struct ServerGlobalParams {
*
- * kFullyUpgradedTo46
- * (4.6, Unset): 4.6 features are available, and new and existing storage
- * engine entries use the 4.6 format
+ * kVersion451
+ * (4.5.1, Unset): 4.5.1 features are available, and new and existing storage
+ * engine entries use the 4.5.1 format
*